==> argo-cd-2.0.2.tar.gz: argo-cd-2.0.2/docs/user-guide/commands/argocd_cert_list.md <==
## argocd cert list

List configured certificates

```
argocd cert list [flags]
```

### Options

```
      --cert-type string          only list certificates of given type, valid: 'ssh','https'
  -h, --help                      help for list
      --hostname-pattern string   only list certificates for hosts matching given glob-pattern
  -o, --output string             Output format. One of: json|yaml|wide (default "wide")
      --sort string               set display sort order for output format wide. One of: hostname|type
```

### Options inherited from parent commands

```
      --auth-token string               Authentication token
      --client-crt string               Client certificate file
      --client-crt-key string           Client certificate key file
      --config string                   Path to Argo CD config (default "/home/user/.argocd/config")
      --grpc-web                        Enables gRPC-web protocol. Useful if Argo CD server is behind proxy which does not support HTTP2.
      --grpc-web-root-path string       Enables gRPC-web protocol. Useful if Argo CD server is behind proxy which does not support HTTP2. Set web root.
  -H, --header strings                  Sets additional header to all requests made by Argo CD CLI. (Can be repeated multiple times to add multiple headers, also supports comma separated headers)
      --insecure                        Skip server certificate and domain verification
      --logformat string                Set the logging format. One of: text|json (default "text")
      --loglevel string                 Set the logging level. One of: debug|info|warn|error (default "info")
      --plaintext                       Disable TLS
      --port-forward                    Connect to a random argocd-server port using port forwarding
      --port-forward-namespace string   Namespace name which should be used for port forwarding
      --server string                   Argo CD server address
      --server-crt string               Server certificate file
```

### SEE ALSO

* [argocd cert](argocd_cert.md)	 - Manage repository certificates and SSH known hosts entries

==> argo-cd-2.1.4.tar.gz: argo-cd-2.1.4/docs/user-guide/commands/argocd_cert_list.md <==
## argocd cert list

List configured certificates

```
argocd cert list [flags]
```

### Options

```
      --cert-type string          only list certificates of given type, valid: 'ssh','https'
  -h, --help                      help for list
      --hostname-pattern string   only list certificates for hosts matching given glob-pattern
  -o, --output string             Output format. One of: json|yaml|wide (default "wide")
      --sort string               set display sort order for output format wide. One of: hostname|type
```

### Options inherited from parent commands

```
      --auth-token string               Authentication token
      --client-crt string               Client certificate file
      --client-crt-key string           Client certificate key file
      --config string                   Path to Argo CD config (default "/home/user/.argocd/config")
      --core                            If set to true then CLI talks directly to Kubernetes instead of talking to Argo CD API server
      --grpc-web                        Enables gRPC-web protocol. Useful if Argo CD server is behind proxy which does not support HTTP2.
      --grpc-web-root-path string       Enables gRPC-web protocol. Useful if Argo CD server is behind proxy which does not support HTTP2. Set web root.
  -H, --header strings                  Sets additional header to all requests made by Argo CD CLI. (Can be repeated multiple times to add multiple headers, also supports comma separated headers)
      --http-retry-max int              Maximum number of retries to establish http connection to Argo CD server
      --insecure                        Skip server certificate and domain verification
      --logformat string                Set the logging format. One of: text|json (default "text")
      --loglevel string                 Set the logging level. One of: debug|info|warn|error (default "info")
      --plaintext                       Disable TLS
      --port-forward                    Connect to a random argocd-server port using port forwarding
      --port-forward-namespace string   Namespace name which should be used for port forwarding
      --server string                   Argo CD server address
      --server-crt string               Server certificate file
```

### SEE ALSO

* [argocd cert](argocd_cert.md)	 - Manage repository certificates and SSH known hosts entries
